@@ -283,16 +283,16 @@ class aurora_sim:
         lTe = np.log10(self._Te)
 
         # get electron impact ionization and radiative recombination rates in units of [s^-1]
-        S_rates = atomic.interp_atom_prof(self.atom_data['scd'],lne, lTe)
-        R_rates = atomic.interp_atom_prof(self.atom_data['acd'],lne, lTe)
+        S_rates = atomic.interp_atom_prof(self.atom_data['scd'],lne, lTe, x_multiply=True)
+        R_rates = atomic.interp_atom_prof(self.atom_data['acd'],lne, lTe, x_multiply=True)
 
         if self.namelist['cxr_flag']:
             # include thermal charge exchange recombination
             lTi = np.log10(self._Ti)
             alpha_CX_rates = atomic.interp_atom_prof(self.atom_data['ccd'], lne, lTi, x_multiply=False)
 
-            # change rates from units of [1/s/cm^3] to [1/s]
-            R_rates += self._n0[:,None] * alpha_CX_rates[:,:R_rates.shape[1],:]   # select only relevant CCD ion stages (useful for Foster scaling)
+            # change rates from units of [1/s/cm^3] to [1/s] - select only relevant CCD ion stages (useful for Foster scaling)
+            R_rates += self._n0[:,None] * alpha_CX_rates[:,:R_rates.shape[1],:]   
 
         if self.namelist['nbi_cxr_flag']:
             # include charge exchange between NBI neutrals and impurities
@@ -326,9 +326,11 @@ class aurora_sim:
         from omfit_classes.utils_math import atomic_element
 
         # background mass number (=2 for D)
+        self.main_element = self.namelist['main_element']
         out = atomic_element(symbol=self.namelist['main_element'])
         spec = list(out.keys())[0]
         self.main_ion_A = int(out[spec]['A'])
+        self.main_ion_Z = int(out[spec]['Z'])
 
         # factor for v = machnumber * sqrt((3T_i+T_e)k/m)
         vpf = self.namelist['SOL_mach']*np.sqrt(q_electron/m_p/self.main_ion_A)  
